.. _contribute_guide:

Contributing to pylint
======================

The contributor guide will help you if you want to contribute to pylint itself.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   contribute
   tests/index
   profiling
   oss_fuzz
   release
   governance
